@@ -1,10 +1,11 @@
 #helper function used in cm_df.transcript (not exported)
 numbtext <-
 function(text.var, width=80, txt.file = NULL, 
-    indent = 4, lengths = NULL, name=NULL) {
+    indent = 4, lengths = NULL, name=NULL, skip = TRUE, space = 2) {
     if (is.null(lengths)){
         lengths <- 1:length(text.var)
     }
+    char <- ifelse(skip, "\n", "")
     zz <- matrix(c(lengths, as.character(text.var)), 
         nrow=2, byrow=TRUE)
     OW <- options()$width
@@ -12,12 +13,13 @@ function(text.var, width=80, txt.file = NULL,
     ind <- paste(rep(" ", indent), collapse = "")
     dimnames(zz) <- list(c(rep(ind, nrow(zz))), c(rep("", ncol(zz))))
     if(!is.null(name)) {
-        cat(paste0("\n", name, ":\n"))
+        message(paste0("\n", name, ":"))
     }
     print(zz, quote = FALSE)
     if (!is.null(txt.file)){
         if(!is.null(name)) {
-            cat(paste0("\n", name, ":\n"), file=txt.file, append = TRUE)
+            cat(paste0(char, name, sprintf(":%s", paste(rep("\n", space), 
+                collapse = ""))), file=txt.file, append = TRUE)
         }
         sink(file=txt.file, append = TRUE)
         print(zz, quote = FALSE)
